@@ -41,6 +41,7 @@ The following code shows how to obtain a meter using the global :class:`.MeterPr
 """
 
 
+import warnings
 from abc import ABC, abstractmethod
 from logging import getLogger
 from os import environ
@@ -74,6 +75,7 @@ from opentelemetry.metrics._internal.instrument import (
 )
 from opentelemetry.util._once import Once
 from opentelemetry.util._providers import _load_provider
+from opentelemetry.util.types import Attributes
 
 _logger = getLogger(__name__)
 
@@ -101,6 +103,7 @@ class MeterProvider(ABC):
         name: str,
         version: Optional[str] = None,
         schema_url: Optional[str] = None,
+        attributes: Optional[Attributes] = None,
     ) -> "Meter":
         """Returns a `Meter` for use by the given instrumentation library.
 
@@ -127,6 +130,7 @@ class MeterProvider(ABC):
                 ``importlib.metadata.version(instrumenting_library_name)``.
 
             schema_url: Optional. Specifies the Schema URL of the emitted telemetry.
+            attributes: Optional. Attributes that are associated with the emitted telemetry.
         """
 
 
@@ -138,9 +142,9 @@ class NoOpMeterProvider(MeterProvider):
         name: str,
         version: Optional[str] = None,
         schema_url: Optional[str] = None,
+        attributes: Optional[Attributes] = None,
     ) -> "Meter":
         """Returns a NoOpMeter."""
-        super().get_meter(name, version=version, schema_url=schema_url)
         return NoOpMeter(name, version=version, schema_url=schema_url)
 
 
@@ -155,6 +159,7 @@ class _ProxyMeterProvider(MeterProvider):
         name: str,
         version: Optional[str] = None,
         schema_url: Optional[str] = None,
+        attributes: Optional[Attributes] = None,
     ) -> "Meter":
         with self._lock:
             if self._real_meter_provider is not None:
@@ -385,8 +390,7 @@ class Meter(ABC):
             description: A description for this instrument and what it measures.
         """
 
-    @abstractmethod
-    def create_gauge(
+    def create_gauge(  # type: ignore # pylint: disable=no-self-use
         self,
         name: str,
         unit: str = "",
@@ -400,6 +404,7 @@ class Meter(ABC):
                 example, ``By`` for bytes. UCUM units are recommended.
             description: A description for this instrument and what it measures.
         """
+        warnings.warn("create_gauge() is not implemented and will be a no-op")
 
     @abstractmethod
     def create_observable_gauge(
@@ -598,7 +603,6 @@ class NoOpMeter(Meter):
         description: str = "",
     ) -> Counter:
         """Returns a no-op Counter."""
-        super().create_counter(name, unit=unit, description=description)
         if self._is_instrument_registered(
             name, NoOpCounter, unit, description
         )[0]:
@@ -619,7 +623,6 @@ class NoOpMeter(Meter):
         description: str = "",
     ) -> Gauge:
         """Returns a no-op Gauge."""
-        super().create_gauge(name, unit=unit, description=description)
         if self._is_instrument_registered(name, NoOpGauge, unit, description)[
             0
         ]:
@@ -640,9 +643,6 @@ class NoOpMeter(Meter):
         description: str = "",
     ) -> UpDownCounter:
         """Returns a no-op UpDownCounter."""
-        super().create_up_down_counter(
-            name, unit=unit, description=description
-        )
         if self._is_instrument_registered(
             name, NoOpUpDownCounter, unit, description
         )[0]:
@@ -664,9 +664,6 @@ class NoOpMeter(Meter):
         description: str = "",
     ) -> ObservableCounter:
         """Returns a no-op ObservableCounter."""
-        super().create_observable_counter(
-            name, callbacks, unit=unit, description=description
-        )
         if self._is_instrument_registered(
             name, NoOpObservableCounter, unit, description
         )[0]:
@@ -692,7 +689,6 @@ class NoOpMeter(Meter):
         description: str = "",
     ) -> Histogram:
         """Returns a no-op Histogram."""
-        super().create_histogram(name, unit=unit, description=description)
         if self._is_instrument_registered(
             name, NoOpHistogram, unit, description
         )[0]:
@@ -714,9 +710,6 @@ class NoOpMeter(Meter):
         description: str = "",
     ) -> ObservableGauge:
         """Returns a no-op ObservableGauge."""
-        super().create_observable_gauge(
-            name, callbacks, unit=unit, description=description
-        )
         if self._is_instrument_registered(
             name, NoOpObservableGauge, unit, description
         )[0]:
@@ -743,9 +736,6 @@ class NoOpMeter(Meter):
         description: str = "",
     ) -> ObservableUpDownCounter:
         """Returns a no-op ObservableUpDownCounter."""
-        super().create_observable_up_down_counter(
-            name, callbacks, unit=unit, description=description
-        )
         if self._is_instrument_registered(
             name, NoOpObservableUpDownCounter, unit, description
         )[0]:
